//
// Inclusion of local header file
//
#include "normal_termination.hpp"

namespace islib
  {
    //
    // Definition of constructor
    //
    normal_termination::normal_termination
      (
        int const parameter_exit_status
      ):
      member_exit_status ( parameter_exit_status )
      {
      }

    //
    // Definition of destructor
    //
    normal_termination::~normal_termination
      (
      )
      throw
      (
      )
      {
      }

    //
    // Definition of non-static member function
    //
    int
      normal_termination::exit_status
      (
      )
      const
      throw
      (
      )
      {
        return this->member_exit_status;
      }

    //
    // Definition of non-static member function
    //
    char const *
      normal_termination::what
      (
      )
      const
      throw
      (
      )
      {
        return 0;
      }
  }

//
// End of file
//
